@@ -67,7 +67,7 @@ class MinimumParser:
 
     def parse(self, target=argv):
         """コマンドラインオプションをパース。target引数でパースするものを指定できます"""
-        self.prog_name = target[0]
+        self.prog_name = target[0].split("/")[-1]
 
         # ヘルプとバージョンをprintするoptionを追加
         self.__add_usage_opt()
